#!/usr/bin/env python3

import argparse
import logging
import os
import re
import sys
import yaml

from Attrap_bot import Attrap_bot

# On paramètre le niveau de verbosité des logs
logging.basicConfig(level=os.environ.get('LOG_LEVEL', 'WARNING').upper())
logger = logging.getLogger(__name__)


def create_config(keys, value):
    if isinstance(value, str):
        if value in ['FalseFalse', 'False', '0']:
            value = False
        if value in ['TrueTrue', 'True', '1']:
            value = True
    if not keys[:-1] == []:
        return create_config(keys[:-1], {keys[-1]: value})
    else:
        return {keys[-1]: value}


def merge_dicts(a: dict, b: dict, path=[]):
    for key in b:
        if key in a:
            if isinstance(a[key], dict) and isinstance(b[key], dict):
                merge_dicts(a[key], b[key], path + [str(key)])
            elif a[key] != b[key]:
                raise Exception()
        else:
            a[key] = b[key]
    return a


parser = argparse.ArgumentParser(
    prog='cli.py',
    description='Recherche les derniers RAA correspondant à une certaine requête et envoie les résultats par email et sur Mastodon'
)

parser.add_argument(
    '--config', '-c',
    action='store',
    help='Fichier de configuration (par défaut: config.yml)'
)

args = parser.parse_args()

if args.config:
    config_file = args.config
else:
    config_file = 'config.yml'

# Si le fichier de configuration existe, on le charge
if os.path.isfile(config_file):
    config = yaml.load(open(config_file, 'r'), Loader=yaml.FullLoader)
# Sinon, on crée la configuration à partir des variables d'environnement
else:
    config = {}
    for var in os.environ:
        if var.startswith('ATTRAP_BOT__'):
            key = var[12:].lower()
            value = os.environ[var]
            created_config = create_config(re.split('__', key), value)
            config = merge_dicts(config, created_config)

    logging.debug(f'Configuration : {config}')

bot = Attrap_bot(config)
bot.analyze()
